import { CommandError } from '@resolve-js/core';

const dispose = async pool => {
  const segment = pool.performanceTracer ? pool.performanceTracer.getSegment() : null;
  const subSegment = segment ? segment.addNewSubsegment('dispose') : null;

  try {
    if (pool.isDisposed) {
      throw new CommandError('Command handler is disposed');
    }

    pool.isDisposed = true;
  } catch (error) {
    if (subSegment != null) {
      subSegment.addError(error);
    }

    throw error;
  } finally {
    if (subSegment != null) {
      subSegment.close();
    }
  }
};

const createCommand = ({
  performanceTracer,
  aggregatesInterop
}) => {
  const pool = {
    isDisposed: false,
    performanceTracer
  };

  const disposableExecutor = async (command) => {
    if (pool.isDisposed) {
      throw new CommandError('Command handler is disposed');
    }

    return await aggregatesInterop.executeCommand(command);
  };

  const api = {
    executeCommand: disposableExecutor,
    dispose: dispose.bind(null, pool)
  };
  const commandExecutor = disposableExecutor.bind(null);
  Object.assign(commandExecutor, api);
  return commandExecutor;
};

export default createCommand;
//# sourceMappingURL=index.js.map