"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("source-map-support/register");

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

var _postgres = require("resolve-cloud-common/postgres");

var _lambda = require("resolve-cloud-common/lambda");

var _utils = require("resolve-cloud-common/utils");

var _core = require("@resolve-js/core");

var _initAwsClients = _interopRequireDefault(require("./init-aws-clients"));

var _initPerformanceTracer = _interopRequireDefault(require("./init-performance-tracer"));

var _lambdaWorker = _interopRequireDefault(require("./lambda-worker"));

var _wrapTrie = _interopRequireDefault(require("../common/wrap-trie"));

var _initUploader = _interopRequireDefault(require("./init-uploader"));

var _gatherEventListeners = _interopRequireDefault(require("../common/gather-event-listeners"));

var _getSubscribeAdapterOptions = _interopRequireDefault(require("./get-subscribe-adapter-options"));

var _metrics = require("./metrics");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _debugLevels.default)('resolve:runtime:cloud-entry');

const index = async ({
  assemblies,
  constants,
  domain
}) => {
  let subSegment = null;
  log.debug(`starting lambda 'cold start'`);
  const domainInterop = (0, _core.initDomain)(domain);

  try {
    log.debug('configuring reSolve framework');
    const resolve = {
      seedClientEnvs: assemblies.seedClientEnvs,
      serverImports: assemblies.serverImports,
      ...domain,
      ...constants,
      routesTrie: (0, _wrapTrie.default)(domain.apiHandlers, constants.rootPath),
      publisher: {},
      assemblies,
      domainInterop,
      eventListeners: (0, _gatherEventListeners.default)(domain, domainInterop),
      upstream: true
    };
    log.debug('preparing performance tracer');
    await (0, _initPerformanceTracer.default)(resolve);
    const segment = resolve.performanceTracer.getSegment();
    subSegment = segment.addNewSubsegment('initResolve');
    Object.defineProperties(resolve, {
      getSubscribeAdapterOptions: {
        value: _getSubscribeAdapterOptions.default
      }
    });
    log.debug('preparing aws clients');
    await (0, _initAwsClients.default)(resolve);
    log.debug('preparing uploader');
    await (0, _initUploader.default)(resolve);

    resolve.sendReactiveEvent = async event => {
      const {
        aggregateId,
        type
      } = event;
      const databaseNameAsId = (0, _postgres.escapeId)(process.env.RESOLVE_EVENT_BUS_DATABASE_NAME);
      const subscriptionsTableNameAsId = (0, _postgres.escapeId)(process.env.RESOLVE_SUBSCRIPTIONS_TABLE_NAME);
      const connectionIdsResult = await (0, _postgres.executeStatement)({
        Region: process.env.AWS_REGION,
        ResourceArn: process.env.RESOLVE_EVENT_STORE_CLUSTER_ARN,
        SecretArn: process.env.RESOLVE_USER_SECRET_ARN,
        Sql: `SELECT "connectionId" FROM ${databaseNameAsId}.${subscriptionsTableNameAsId}
          WHERE (
             ${databaseNameAsId}.${subscriptionsTableNameAsId}."eventTypes" #>
             ${(0, _postgres.escapeStr)(`{${JSON.stringify(type)}}`)} =
             CAST('true' AS jsonb)
            OR
             ${databaseNameAsId}.${subscriptionsTableNameAsId}."eventTypes" #> '{}' =
             CAST('null' AS jsonb) 
            ) AND (
             ${databaseNameAsId}.${subscriptionsTableNameAsId}."aggregateIds" #>
             ${(0, _postgres.escapeStr)(`{${JSON.stringify(aggregateId)}}`)} =
             CAST('true' AS jsonb)
            OR
             ${databaseNameAsId}.${subscriptionsTableNameAsId}."aggregateIds" #> '{}' =
             CAST('null' AS jsonb) 
          )`
      });
      const errors = [];
      await Promise.all(connectionIdsResult.map(({
        connectionId
      }) => (0, _lambda.invokeFunction)({
        Region: process.env.AWS_REGION,
        FunctionName: process.env.RESOLVE_WEBSOCKET_LAMBDA_ARN,
        Payload: {
          type: 'send',
          connectionId,
          data: {
            type: 'event',
            event,
            connectionIdsResult
          }
        }
      }).catch((0, _utils.errorBoundary)(errors))));

      if (errors.length > 0) {
        log.warn(`Failed push event to websocket. ${errors}`);
      }
    };

    log.debug(`lambda 'cold start' succeeded`);
    return _lambdaWorker.default.bind(null, resolve);
  } catch (error) {
    log.error(`lambda 'cold start' failure`, error);
    subSegment.addError(error);
    await (0, _metrics.putInternalError)(error);
  } finally {
    if (subSegment != null) {
      subSegment.close();
    }
  }
};

var _default = index;
exports.default = _default;
//# sourceMappingURL=index.js.map