"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

var _metrics = require("./metrics");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getLog = name => (0, _debugLevels.default)(`resolve:cloud:scheduler:${name}`);

const initMonitoring = resolve => {
  const log = getLog('monitoring');
  resolve.monitoring = {
    error: async (error, part, meta) => {
      try {
        log.verbose(`Collect error for '${part}' part`);

        switch (part) {
          case 'command':
            {
              await (0, _metrics.putCommandMetrics)(meta.command.aggregateName, meta.command.type, meta.command.aggregateId, error);
              break;
            }

          case 'readModelProjection':
            {
              await (0, _metrics.putReadModelProjectionMetrics)(meta.readModelName, meta.eventType, error);
              break;
            }

          case 'readModelResolver':
            {
              await (0, _metrics.putReadModelResolverMetrics)(meta.readModelName, meta.resolverName, error);
              break;
            }

          case 'viewModelProjection':
            {
              await (0, _metrics.putViewModelProjectionMetrics)(meta.viewModelName, meta.eventType, error);
              break;
            }

          case 'viewModelResolver':
            {
              await (0, _metrics.putViewModelResolverMetrics)(meta.readModelName, error);
              break;
            }

          case 'apiHandler':
            {
              await (0, _metrics.putApiHandlerMetrics)(meta.path, error);
              break;
            }

          case 'sagaProjection':
            {
              await (0, _metrics.putSagaMetrics)(meta.sagaName, meta.eventType, error);
              break;
            }

          default:
            {
              log.verbose(`Unknown error part: ${part}`);
              break;
            }
        }
      } catch (error) {
        log.verbose(`Failed to collect error`, error);
      }
    }
  };
};

var _default = initMonitoring;
exports.default = _default;
//# sourceMappingURL=init-monitoring.js.map