"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extractErrorHttpCode = _interopRequireDefault(require("../utils/extract-error-http-code"));

var _getRootBasedUrl = _interopRequireDefault(require("../utils/get-root-based-url"));

var _extractRequestBody = _interopRequireDefault(require("../utils/extract-request-body"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const queryHandler = async (req, res) => {
  const segment = req.resolve.performanceTracer.getSegment();
  const subSegment = segment.addNewSubsegment('query');

  try {
    var _result$meta, _result$meta2;

    const baseQueryUrl = (0, _getRootBasedUrl.default)(req.resolve.rootPath, '/api/query/');
    const paramsPath = req.path.substring(baseQueryUrl.length);
    const [modelName, modelOptions] = paramsPath.split('/');

    if (modelName == null || modelOptions == null) {
      const error = new Error('Invalid "modelName" and/or "modelOptions" parameters');
      error.code = 400;
      throw error;
    }

    const modelArgs = (0, _extractRequestBody.default)(req);
    const result = await req.resolve.executeQuery.read({
      modelName,
      modelOptions,
      modelArgs,
      jwt: req.jwt
    });
    subSegment.addAnnotation('modelName', modelName);
    subSegment.addAnnotation('origin', 'resolve:query');
    res.status(200);
    res.setHeader('Content-Type', 'application/json');

    if ((((_result$meta = result.meta) === null || _result$meta === void 0 ? void 0 : _result$meta.aggregateIds) != null || ((_result$meta2 = result.meta) === null || _result$meta2 === void 0 ? void 0 : _result$meta2.eventTypes) != null) && modelArgs.origin != null) {
      const {
        aggregateIds
      } = result.meta || {};
      const subscriptionAggregateIds = Array.isArray(aggregateIds) || aggregateIds === '*' || aggregateIds == null ? aggregateIds : [aggregateIds];
      const subscribeOptions = await req.resolve.getSubscribeAdapterOptions(req.resolve, modelArgs.origin, result.meta.eventTypes, subscriptionAggregateIds);
      res.setHeader('X-Resolve-View-Model-Subscription', JSON.stringify(subscribeOptions));
    }

    res.end(await req.resolve.executeQuery.serializeState({
      modelName,
      state: result,
      jwt: req.jwt
    }));
  } catch (error) {
    const errorCode = (0, _extractErrorHttpCode.default)(error);
    res.status(errorCode);
    res.setHeader('Content-Type', 'text/plain');
    res.end(error.message);
    subSegment.addError(error);
  } finally {
    subSegment.close();
  }
};

var _default = queryHandler;
exports.default = _default;
//# sourceMappingURL=query-handler.js.map