"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _crypto = _interopRequireDefault(require("crypto"));

var _fileType = _interopRequireDefault(require("file-type"));

var _extractRequestBody = _interopRequireDefault(require("../utils/extract-request-body"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _debugLevels.default)('resolve:runtime:uploader-handler');

const uploaderHandler = async (req, res) => {
  try {
    const {
      directory,
      bucket,
      secretKey
    } = req.resolve.uploader;

    const bucketPath = _path.default.join(directory, bucket);

    if (!_fs.default.existsSync(bucketPath)) {
      _fs.default.mkdirSync(bucketPath, {
        recursive: true
      });
    }

    if (req.method === 'POST' || req.method === 'PUT') {
      const {
        dir,
        uploadId
      } = req.query;

      const dirName = _path.default.join(directory, bucket, dir);

      if (_path.default.relative(bucketPath, dirName).startsWith('..')) {
        throw new Error(`The specified parameter "dir" ${dir} is not valid`);
      }

      if (!_fs.default.existsSync(dirName)) {
        _fs.default.mkdirSync(dirName, {
          recursive: true
        });
      }

      let body = null;
      let data = null;

      if (req.method === 'POST') {
        body = (0, _extractRequestBody.default)(req);
        data = Buffer.from(body.file.contentData, 'latin1');

        _fs.default.writeFileSync(`${dirName}/${uploadId}.metadata`, JSON.stringify({
          'Content-Type': body.file.contentType
        }), {
          flag: 'w+',
          encoding: 'utf8'
        });
      } else {
        body = req.body;
        data = Buffer.from(body, 'latin1');

        _fs.default.writeFileSync(`${dirName}/${uploadId}.metadata`, JSON.stringify({
          'Content-Type': (0, _fileType.default)(data) != null ? (0, _fileType.default)(data).mime : 'text/plain'
        }), {
          flag: 'w+',
          encoding: 'utf8'
        });
      }

      _fs.default.writeFileSync(`${dirName}/${uploadId}`, data, {
        flag: 'w+'
      });
    } else if (req.method === 'GET') {
      const uploadParams = req.matchedParams.params;

      if (uploadParams == null || uploadParams.constructor !== String) {
        return res.status(403).end('Invalid URL.');
      }

      const uploadParamsArray = uploadParams.split('/');
      const requestDir = uploadParamsArray.slice(0, -1).join('/');
      const [uploadId] = uploadParamsArray.slice(-1);
      const {
        token
      } = req.query;

      if (token == null || token === '') {
        return res.status(403).end('Signature does not found.');
      }

      const [payload, signature] = token.split('*');

      if (payload == null || signature == null) {
        return res.status(403).end('Invalid Signature.');
      }

      const {
        dir,
        expireTime
      } = JSON.parse(Buffer.from(payload, 'base64').toString());

      if (requestDir !== dir) {
        return res.status(403).end('Invalid dir.');
      }

      const encodePayload = _crypto.default.createHmac('md5', secretKey).update(payload).digest('hex');

      if (signature !== encodePayload) {
        return res.status(403).end('Signature does not match.');
      }

      if (Date.now() > expireTime) {
        return res.status(403).end('Time is over.');
      }

      const metadata = JSON.parse(_fs.default.readFileSync(_path.default.join(bucketPath, dir, `${uploadId}.metadata`), 'utf8'));

      const file = _fs.default.readFileSync(_path.default.join(bucketPath, dir, uploadId));

      res.setHeader('Content-Type', metadata['Content-Type']);
      res.setHeader('Content-Disposition', 'inline');
      res.end(file);
    }
  } catch (err) {
    log.warn('Uploader handler error', err);
    await res.status(500);
    await res.setHeader('Content-Type', 'text/plain');
    await res.end(err.toString());
  }
};

var _default = uploaderHandler;
exports.default = _default;
//# sourceMappingURL=uploader-handler.js.map