"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "CreateQueryOptions", {
  enumerable: true,
  get: function () {
    return _types.CreateQueryOptions;
  }
});
Object.defineProperty(exports, "OMIT_BATCH", {
  enumerable: true,
  get: function () {
    return _batch.OMIT_BATCH;
  }
});
Object.defineProperty(exports, "STOP_BATCH", {
  enumerable: true,
  get: function () {
    return _batch.STOP_BATCH;
  }
});
exports.default = void 0;

var _wrapReadModel = _interopRequireDefault(require("./wrap-read-model"));

var _wrapViewModel = _interopRequireDefault(require("./wrap-view-model"));

var _types = require("./types");

var _batch = require("./batch");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dispose = async models => {
  for (const modelName of Object.keys(models)) {
    await models[modelName].dispose();
  }
};

const interopApi = async (models, key, ...args) => {
  if (args.length !== 1 || Object(args[0]) !== args[0]) {
    throw new TypeError(`Invalid resolve-query method "${key}" arguments ${JSON.stringify(args)}`);
  } // eslint-disable-next-line prefer-const


  let {
    eventSubscriber,
    modelName,
    ...parameters
  } = args[0];

  if (eventSubscriber == null && modelName == null) {
    throw new Error(`Either "eventSubscriber" nor "modelName" is null`);
  } else if (modelName == null) {
    modelName = eventSubscriber;
  }

  if (models[modelName] == null) {
    const error = new Error(`Read/view model "${modelName}" does not exist`);
    error.code = 422;
    throw error;
  }

  const method = models[modelName][key];

  if (typeof method !== 'function') {
    throw new TypeError(`Model "${modelName}" does not implement method "${key}"`);
  }

  return await method(parameters);
};

const createQuery = params => {
  const models = {};
  const {
    viewModelsInterop,
    readModelsInterop,
    ...imports
  } = params;

  for (const model of Object.values(readModelsInterop)) {
    models[model.name] = (0, _wrapReadModel.default)({
      interop: model,
      ...imports
    });
  }

  for (const model of Object.values(viewModelsInterop)) {
    models[model.name] = (0, _wrapViewModel.default)({
      interop: model,
      ...imports
    });
  }

  const read = interopApi.bind(null, models, 'read');
  const api = new Proxy(read, {
    get(_, key) {
      if (key === 'bind' || key === 'apply' || key === 'call') {
        return read[key].bind(read);
      } else if (key === 'dispose') {
        return dispose.bind(null, models);
      } else {
        return interopApi.bind(null, models, key);
      }
    },

    set() {
      throw new TypeError(`Resolve-query API is immutable`);
    }

  });
  return api;
};

var _default = createQuery;
exports.default = _default;
//# sourceMappingURL=index.js.map