"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var contentDisposition = _interopRequireWildcard(require("content-disposition"));

var _iconvLite = _interopRequireDefault(require("iconv-lite"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const convertCodepage = (content, fromEncoding, toEncoding) => _iconvLite.default.decode(_iconvLite.default.encode(content, fromEncoding), toEncoding);

const extractRequestBody = req => {
  if (req.body == null || req.body === '') {
    return req.query;
  }

  const [contentType, optionsEntry] = req.headers['content-type'] != null ? String(req.headers['content-type']).split(';').map(value => value.trim().toLowerCase()) : [];
  let bodyFields = {};

  switch (contentType) {
    case 'application/json':
      {
        bodyFields = JSON.parse(req.body);
        break;
      }

    case 'application/x-www-form-urlencoded':
      {
        bodyFields = req.body.split('&').reduce((acc, pair) => {
          let [key, value] = pair.split('=').map(decodeURIComponent);
          acc[key] = value;
          return acc;
        }, {});
        break;
      }

    case 'multipart/form-data':
      {
        bodyFields = {};
        let boundary = null;

        if (optionsEntry != null && optionsEntry.startsWith('boundary=')) {
          boundary = optionsEntry.substring('boundary='.length);
        }

        if (boundary == null) {
          throw new Error('Invalid boundary for multipart/form-data');
        }

        const boundaryRegexp = new RegExp(`\r?\n--${String(boundary).replace( // eslint-disable-next-line no-useless-escape
        /[-\/\\^$*+?.()|[\]{}]/g, '\\$&')}(?:(?:\r?\n)|--)`, 'ig');
        const contentArray = `\n${req.body}\n`.split(boundaryRegexp).slice(1, -1);

        for (let index = 0; index < contentArray.length; index++) {
          const separatorMatch = contentArray[index].match(/\r?\n\r?\n/);

          if (separatorMatch == null) {
            throw new Error('Invalid inline body separator for multipart/form-data');
          }

          const separatorIndex = separatorMatch.index;
          const separatorLength = separatorMatch[0].length;
          const inlineHeadersString = contentArray[index].substring(0, separatorIndex);
          const inlineBodyString = contentArray[index].substring(separatorIndex + separatorLength);
          const inlineHeaders = inlineHeadersString.split(/\r?\n/g).reduce((acc, content) => {
            const [inlineHeaderName, ...inlineHeaderContent] = content.split( // eslint-disable-next-line no-useless-escape
            /\: /g);
            const inlineHeaderValue = inlineHeaderContent.join(': ');
            acc[inlineHeaderName.toLowerCase()] = inlineHeaderValue;
            return acc;
          }, {});
          const [inlineContentType, inlineCharset] = String(inlineHeaders['content-type']).split(';').map(value => value.trim().toLowerCase());
          const {
            type: dispositionType,
            parameters: {
              name,
              filename
            }
          } = contentDisposition.parse(inlineHeaders['content-disposition']);

          if (dispositionType !== 'form-data') {
            throw new Error('Invalid inline content disposition for multipart/form-data');
          }

          bodyFields[name] = {
            contentType: inlineContentType,
            contentData: inlineCharset != null ? convertCodepage(inlineBodyString, 'latin1', inlineCharset) : inlineBodyString,
            contentCharset: inlineCharset != null ? inlineCharset : 'latin1',
            filename
          };
        }

        break;
      }

    default:
      {
        throw new Error('Unsupported Content-Type in request body');
      }
  }

  return Object.assign(bodyFields, req.query);
};

var _default = extractRequestBody;
exports.default = _default;
//# sourceMappingURL=extract-request-body.js.map