"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _routeTrie = _interopRequireDefault(require("route-trie"));

var _commandHandler = _interopRequireDefault(require("./handlers/command-handler"));

var _queryHandler = _interopRequireDefault(require("./handlers/query-handler"));

var _markupHandler = _interopRequireDefault(require("./handlers/markup-handler"));

var _uploaderHandler = _interopRequireDefault(require("./handlers/uploader-handler"));

var _getRootBasedUrl = _interopRequireDefault(require("./utils/get-root-based-url"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const wrapTrie = (apiHandlers, rootPath) => {
  const trie = new _routeTrie.default({
    ignoreCase: true,
    fixedPathRedirect: true,
    trailingSlashRedirect: true
  });
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/api/query/:wildcard*')).handle('GET', _queryHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/api/query/:wildcard*')).handle('POST', _queryHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/api/query')).handle('GET', _queryHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/api/query')).handle('POST', _queryHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/api/commands/:wildcard*')).handle('POST', _commandHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/api/commands')).handle('POST', _commandHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/uploader')).handle('POST', _uploaderHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/uploader')).handle('PUT', _uploaderHandler.default);
  trie.define((0, _getRootBasedUrl.default)(rootPath, '/uploader/:params*')).handle('GET', _uploaderHandler.default);

  for (const {
    method,
    path,
    handler
  } of apiHandlers) {
    trie.define((0, _getRootBasedUrl.default)(rootPath, path)).handle(String(method).toUpperCase(), handler);
  }

  try {
    trie.define((0, _getRootBasedUrl.default)(rootPath, '/:markup*')).handle('GET', _markupHandler.default);
  } catch (e) {}

  return trie;
};

var _default = wrapTrie;
exports.default = _default;
//# sourceMappingURL=wrap-trie.js.map