"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const createPubsubManager = () => {
  const map = new Map();
  const pubsubManager = {
    connect({
      client,
      connectionId,
      eventTypes,
      aggregateIds
    }) {
      if (!map.has(connectionId)) {
        map.set(connectionId, {
          client,
          eventTypes,
          aggregateIds
        });
      }
    },

    disconnect({
      connectionId
    }) {
      if (!map.has(connectionId)) {
        return;
      }

      map.delete(connectionId);
    },

    getConnection({
      connectionId
    }) {
      const connection = map.get(connectionId);
      return connection;
    },

    async dispatch({
      event
    }) {
      const promises = [];
      const {
        type,
        aggregateId
      } = event;

      for (const connectionId of map.keys()) {
        var _eventTypes$includes, _aggregateIds$include;

        const {
          eventTypes,
          aggregateIds,
          client
        } = map.get(connectionId);

        if ((eventTypes == null || (eventTypes === null || eventTypes === void 0 ? void 0 : (_eventTypes$includes = eventTypes.includes) === null || _eventTypes$includes === void 0 ? void 0 : _eventTypes$includes.call(eventTypes, type))) && (aggregateIds == null || (aggregateIds === null || aggregateIds === void 0 ? void 0 : (_aggregateIds$include = aggregateIds.includes) === null || _aggregateIds$include === void 0 ? void 0 : _aggregateIds$include.call(aggregateIds, aggregateId)))) {
          promises.push(client(JSON.stringify({
            type: 'event',
            event
          })));
        }
      }

      await Promise.all(promises);
    }

  };
  return pubsubManager;
};

var _default = createPubsubManager;
exports.default = _default;
//# sourceMappingURL=create-pubsub-manager.js.map