"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _util = require("util");

var _stream = require("stream");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const importEventStoreHandler = options => async (req, res) => {
  const {
    eventstoreAdapter
  } = req.resolve;

  try {
    const {
      directory
    } = options;

    const eventsFile = _path.default.join(directory, 'events.db');

    const secretsFile = _path.default.join(directory, 'secrets.db');

    if (!_fs.default.existsSync(eventsFile)) {
      throw new Error(`No such file or directory "${eventsFile}"`);
    }

    if (!_fs.default.existsSync(secretsFile)) {
      throw new Error(`No such file or directory "${secretsFile}"`);
    }

    await (0, _util.promisify)(_stream.pipeline)(_fs.default.createReadStream(eventsFile), eventstoreAdapter.importEvents());
    await (0, _util.promisify)(_stream.pipeline)(_fs.default.createReadStream(secretsFile), eventstoreAdapter.importSecrets());
    res.end('ok');
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    res.status(500);
    res.end(String(error));
  }
};

var _default = importEventStoreHandler;
exports.default = _default;
//# sourceMappingURL=import-event-store-handler.js.map