"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("source-map-support/register");

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

var _core = require("@resolve-js/core");

var _initPerformanceTracer = _interopRequireDefault(require("./init-performance-tracer"));

var _initExpress = _interopRequireDefault(require("./init-express"));

var _initWebsockets = _interopRequireDefault(require("./init-websockets"));

var _startExpress = _interopRequireDefault(require("./start-express"));

var _emptyWorker = _interopRequireDefault(require("./empty-worker"));

var _wrapTrie = _interopRequireDefault(require("../common/wrap-trie"));

var _initUploader = _interopRequireDefault(require("./init-uploader"));

var _initScheduler = _interopRequireDefault(require("./init-scheduler"));

var _gatherEventListeners = _interopRequireDefault(require("../common/gather-event-listeners"));

var _initResolve = _interopRequireDefault(require("../common/init-resolve"));

var _disposeResolve = _interopRequireDefault(require("../common/dispose-resolve"));

var _multiplexAsync = _interopRequireDefault(require("../common/utils/multiplex-async"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _debugLevels.default)('resolve:runtime:local-entry');

const localEntry = async ({
  assemblies,
  constants,
  domain
}) => {
  try {
    const domainInterop = await (0, _core.initDomain)(domain);
    const resolve = {
      instanceId: `${process.pid}${Math.floor(Math.random() * 100000)}`,
      seedClientEnvs: assemblies.seedClientEnvs,
      serverImports: assemblies.serverImports,
      ...domain,
      ...constants,
      routesTrie: (0, _wrapTrie.default)(domain.apiHandlers, constants.rootPath),
      assemblies,
      domainInterop,
      eventListeners: (0, _gatherEventListeners.default)(domain, domainInterop),
      upstream: domain.apiHandlers.findIndex(({
        method,
        path
      }) => method === 'OPTIONS' && path === '/SKIP_COMMANDS') < 0
    };
    resolve.eventSubscriberDestination = 'LOCAL'; // TODO

    resolve.invokeEventSubscriberAsync = _multiplexAsync.default.bind(null, async (eventSubscriber, method, parameters) => {
      const currentResolve = Object.create(resolve);

      try {
        await (0, _initResolve.default)(currentResolve);
        const rawMethod = currentResolve.eventSubscriber[method];

        if (typeof rawMethod !== 'function') {
          throw new TypeError(method);
        }

        const result = await rawMethod.call(currentResolve.eventSubscriber, {
          eventSubscriber,
          ...parameters
        });
        return result;
      } finally {
        await (0, _disposeResolve.default)(currentResolve);
      }
    });
    await (0, _initPerformanceTracer.default)(resolve);
    await (0, _initExpress.default)(resolve);
    await (0, _initWebsockets.default)(resolve);
    await (0, _initUploader.default)(resolve);
    await (0, _initScheduler.default)(resolve);
    await (0, _startExpress.default)(resolve);
    log.debug('Local entry point cold start success');
    return _emptyWorker.default;
  } catch (error) {
    log.error('Local entry point cold start failure', error);
  }
};

var _default = localEntry;
exports.default = _default;
//# sourceMappingURL=index.js.map