"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _crypto = _interopRequireDefault(require("crypto"));

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _debugLevels.default)('resolve-performance-tracer');

const createEmptySegment = () => {
  const segment = {
    trace_id: null,
    id: null,
    name: null,
    start_time: null,
    end_time: null,
    delta_time: null,
    annotations: null,
    error: null,
    subsegments: []
  };
  Object.defineProperty(segment, 'toJSON', {
    value: () => '',
    writable: true,
    enumerable: true,
    configurable: true
  });
  return segment;
};

const initPerformanceTracer = resolve => {
  let segment = createEmptySegment();
  let traceId = process.env.RESOLVE_LOCAL_TRACE_ID;
  segment.trace_id = traceId;
  Object.defineProperty(resolve, 'performanceTracer', {
    value: {
      getSegment: () => {
        if (traceId !== process.env.RESOLVE_LOCAL_TRACE_ID) {
          segment = createEmptySegment();
          traceId = process.env.RESOLVE_LOCAL_TRACE_ID;
          segment.trace_id = traceId;
        }

        return {
          addNewSubsegment: subsegmentName => {
            const subsegment = createEmptySegment();
            segment.subsegments.push(subsegment);
            subsegment.id = _crypto.default.randomBytes(Math.ceil(16 / 2)).toString('hex').slice(0, 16);
            subsegment.name = subsegmentName;
            subsegment.start_time = Date.now();
            subsegment.annotations = {};
            subsegment.errors = [];
            const prevSegment = segment;
            segment = subsegment;
            return {
              addAnnotation: (annotationName, data) => {
                subsegment.annotations[annotationName] = data;
              },
              addError: error => {
                subsegment.errors.push(`${error.code ? `${error.code}: ` : ''}${error.message || ''}`);
              },
              close: () => {
                subsegment.end_time = Date.now();
                subsegment.delta_time = subsegment.end_time - subsegment.start_time;

                if (subsegment.errors.length > 0) {
                  subsegment.error = subsegment.errors.join('; ');
                } else {
                  delete subsegment.error;
                }

                delete subsegment.errors;

                if (subsegment.subsegments.length === 0) {
                  delete subsegment.subsegments;
                }

                if (subsegment.trace_id == null) {
                  delete subsegment.trace_id;
                }

                delete segment.toJSON;

                if (process.env.DEBUG) {
                  log.verbose(JSON.stringify(subsegment, null, 2));
                }

                segment = prevSegment;
              }
            };
          }
        };
      }
    }
  });
};

var _default = initPerformanceTracer;
exports.default = _default;
//# sourceMappingURL=init-performance-tracer.js.map