"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _initResolve = _interopRequireDefault(require("../common/init-resolve"));

var _disposeResolve = _interopRequireDefault(require("../common/dispose-resolve"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const errorHandler = async error => {
  throw error;
};

const initScheduler = resolve => {
  const timeouts = new Set();
  let flowPromise = Promise.resolve();
  resolve.scheduler = {
    async addEntries(array) {
      for (const entry of array) {
        // eslint-disable-next-line no-loop-func
        const timeout = setTimeout(() => {
          flowPromise = flowPromise.then(async () => {
            timeouts.delete(timeout);
            const currentResolve = Object.create(resolve);

            try {
              await (0, _initResolve.default)(currentResolve);
              await currentResolve.executeSchedulerCommand({
                aggregateName: resolve.domainInterop.sagaDomain.schedulerName,
                aggregateId: entry.taskId,
                type: 'execute',
                payload: {
                  date: entry.date,
                  command: entry.command
                }
              });
            } finally {
              await (0, _disposeResolve.default)(currentResolve);
            }
          }).catch(async error => {
            if (typeof errorHandler === 'function') {
              await errorHandler(error);
            } else {
              throw error;
            }
          });
        }, new Date(entry.date).getTime() - Date.now());
        timeouts.add(timeout);
      }
    },

    async clearEntries() {
      for (const timeout of timeouts.values()) {
        clearTimeout(timeout);
      }

      timeouts.clear();
    }

  };
};

var _default = initScheduler;
exports.default = _default;
//# sourceMappingURL=init-scheduler.js.map