"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const queryIsReadyHandler = async (req, res) => {
  try {
    const {
      eventstoreAdapter,
      eventSubscriber,
      eventListeners
    } = req.resolve;
    const queryIsReadyPromises = [];

    for (const [key, {
      eventTypes
    }] of eventListeners) {
      queryIsReadyPromises.push((async () => {
        const latestEvent = await eventstoreAdapter.getLatestEvent({
          eventTypes
        });

        if (latestEvent == null) {
          return;
        }

        let successEvent, failedEvent;

        while (failedEvent == null) {
          void ({
            successEvent,
            failedEvent
          } = await eventSubscriber.status({
            eventSubscriber: key
          }));

          if (successEvent != null && successEvent.timestamp >= latestEvent.timestamp) {
            break;
          }

          await new Promise(resolve => setTimeout(resolve, 1000));
        }
      })());
    }

    await Promise.all(queryIsReadyPromises);
    res.end('ok');
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    res.status(500);
    res.end(String(error));
  }
};

var _default = queryIsReadyHandler;
exports.default = _default;
//# sourceMappingURL=query-is-ready-handler.js.map