"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _invokeFilterErrorTypes = _interopRequireDefault(require("../common/utils/invoke-filter-error-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const resetDomainHandler = options => async (req, res) => {
  const {
    eventstoreAdapter,
    eventSubscriber,
    readModels,
    sagas,
    domainInterop: {
      sagaDomain
    },
    applicationName
  } = req.resolve;

  try {
    const {
      dropEventStore,
      dropEventSubscriber,
      dropReadModels,
      dropSagas
    } = options;

    if (dropEventStore) {
      await (0, _invokeFilterErrorTypes.default)(eventstoreAdapter.drop.bind(eventstoreAdapter), [_eventstoreBase.EventstoreResourceNotExistError]);
      await (0, _invokeFilterErrorTypes.default)(eventstoreAdapter.init.bind(eventstoreAdapter), [_eventstoreBase.EventstoreResourceAlreadyExistError]);
    }

    const dropReadModelsSagasErrors = [];

    if (dropReadModels) {
      for (const {
        name
      } of readModels) {
        try {
          await eventSubscriber.reset({
            eventSubscriber: name
          });
        } catch (error) {
          dropReadModelsSagasErrors.push(error);
        }
      }
    }

    if (dropSagas) {
      for (const {
        name
      } of [...sagaDomain.getSagasSchedulersInfo().map(({
        name
      }) => ({
        name
      })), ...sagas]) {
        try {
          await eventSubscriber.reset({
            eventSubscriber: name
          });
        } catch (error) {
          dropReadModelsSagasErrors.push(error);
        }
      }
    }

    if (dropEventSubscriber) {
      const eventSubscribers = await eventstoreAdapter.getEventSubscribers({
        applicationName
      });

      for (const {
        eventSubscriber
      } of eventSubscribers) {
        await eventstoreAdapter.removeEventSubscriber({
          applicationName,
          eventSubscriber
        });
      }
    }

    res.end('ok');
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    res.status(500);
    res.end(String(error));
  }
};

var _default = resetDomainHandler;
exports.default = _default;
//# sourceMappingURL=reset-domain-handler.js.map