"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _initResolve = _interopRequireDefault(require("../common/init-resolve"));

var _disposeResolve = _interopRequireDefault(require("../common/dispose-resolve"));

var _bootstrap = _interopRequireDefault(require("../common/bootstrap"));

var _invokeFilterErrorTypes = _interopRequireDefault(require("../common/utils/invoke-filter-error-types"));

var _eventstoreBase = require("@resolve-js/eventstore-base");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const host = '0.0.0.0';

const startExpress = async resolve => {
  const {
    port,
    server,
    upstream
  } = resolve;
  const currentResolve = Object.create(resolve);

  try {
    await (0, _initResolve.default)(currentResolve);
    const {
      eventstoreAdapter
    } = currentResolve;
    await (0, _invokeFilterErrorTypes.default)(eventstoreAdapter.init.bind(eventstoreAdapter), [_eventstoreBase.EventstoreResourceAlreadyExistError]);
    await (0, _bootstrap.default)(currentResolve);
    const notReadyListeners = new Set([...resolve.eventListeners.keys()]);

    while (upstream && notReadyListeners.size > 0) {
      for (const eventSubscriber of notReadyListeners) {
        const {
          successEvent,
          failedEvent,
          errors
        } = await currentResolve.eventSubscriber.status({
          eventSubscriber
        });

        if (successEvent != null || failedEvent != null || Array.isArray(errors) && errors.length > 0) {
          notReadyListeners.delete(eventSubscriber);
        }
      }

      await new Promise(resolve => setTimeout(resolve, 1000));
    }
  } finally {
    await (0, _disposeResolve.default)(currentResolve);
  }

  await new Promise((resolve, reject) => server.listen(port, host, async error => {
    if (error) {
      return reject(error);
    } // eslint-disable-next-line no-console


    console.log(`Application listening on port ${port}!`);
    return resolve();
  }));
  server.on('error', err => {
    throw err;
  });
};

var _default = startExpress;
exports.default = _default;
//# sourceMappingURL=start-express.js.map